@@ -1,4 +1,4 @@
-use std::{env, fmt, io, path::Path, sync::mpsc, time::Duration};
+use std::{env, fmt, fs, io, panic, path::Path, sync::mpsc, time::Duration};
 
 use crate::{
     buffer::parse_path_and_position,
@@ -47,16 +47,25 @@ pub enum ApplicationEvent {
     },
 }
 
-fn restore_screen(stdout: &mut io::StdoutLock) {
-    use io::Write;
-    let _ = stdout.write_all(ui::EXIT_ALTERNATE_BUFFER_CODE);
-    let _ = stdout.write_all(ui::SHOW_CURSOR_CODE);
-    let _ = stdout.write_all(ui::RESET_STYLE_CODE);
-    let _ = stdout.flush();
+pub struct ApplicationEventSender(mpsc::Sender<ApplicationEvent>);
+impl ApplicationEventSender {
+    pub fn send(&self, event: ApplicationEvent) -> Result<(), AnyError> {
+        match self.0.send(event) {
+            Ok(()) => Ok(()),
+            Err(_) => Err(AnyError),
+        }
+    }
 }
 
 pub struct ServerApplication;
 impl ServerApplication {
+    pub fn platform_request_channel() -> (
+        mpsc::SyncSender<PlatformRequest>,
+        mpsc::Receiver<PlatformRequest>,
+    ) {
+        mpsc::sync_channel(32)
+    }
+
     pub const fn connection_buffer_len() -> usize {
         512
     }
@@ -65,28 +74,28 @@ impl ServerApplication {
         Duration::from_secs(1)
     }
 
-    pub fn run(args: Args, mut platform: Platform) -> mpsc::Sender<ApplicationEvent> {
+    pub fn run(args: Args, mut platform: Platform) -> ApplicationEventSender {
         let current_dir = env::current_dir().expect("could not retrieve the current directory");
         let editor = Editor::new(current_dir);
         let clients = ClientManager::new();
 
         let source_default_config = !args.no_default_config;
         let (event_sender, event_receiver) = mpsc::channel();
-        let event_sender_clone = event_sender.clone();
+        let application_event_sender = ApplicationEventSender(event_sender.clone());
         std::thread::spawn(move || {
             let _ = Self::run_application(
                 source_default_config,
                 editor,
                 clients,
                 &mut platform,
-                event_sender_clone,
+                event_sender,
                 event_receiver,
             );
             platform.enqueue_request(PlatformRequest::Exit);
             platform.flush_requests();
         });
 
-        event_sender
+        application_event_sender
     }
 
     fn run_application(
@@ -144,6 +153,16 @@ impl ServerApplication {
                         while let Some(event) = events.next(&client_event_receiver) {
                             match editor.on_client_event(platform, &mut clients, event) {
                                 EditorControlFlow::Continue => (),
+                                EditorControlFlow::Suspend => {
+                                    let mut buf = platform.buf_pool.acquire();
+                                    let write = buf.write();
+                                    ServerEvent::Suspend.serialize(write);
+                                    let buf = buf.share();
+                                    platform.enqueue_request(PlatformRequest::WriteToClient {
+                                        handle,
+                                        buf,
+                                    });
+                                }
                                 EditorControlFlow::Quit => {
                                     platform
                                         .enqueue_request(PlatformRequest::CloseClient { handle });
@@ -274,15 +293,8 @@ impl<'stdout> ClientApplication<'stdout> {
             }
         }
 
+        self.reinit_screen();
         if !self.is_pipped {
-            use io::Write;
-            self.stdout
-                .write_all(ui::ENTER_ALTERNATE_BUFFER_CODE)
-                .unwrap();
-            self.stdout.write_all(ui::HIDE_CURSOR_CODE).unwrap();
-            self.stdout.write_all(ui::MODE_256_COLORS_CODE).unwrap();
-            self.stdout.flush().unwrap();
-
             if args.as_client.is_none() {
                 ClientEvent::Key(self.handle, Key::None).serialize(&mut self.server_write_buf);
             }
@@ -295,13 +307,37 @@ impl<'stdout> ClientApplication<'stdout> {
         self.server_write_buf.as_slice()
     }
 
+    pub fn reinit_screen(&mut self) {
+        if self.is_pipped {
+            return;
+        }
+
+        use io::Write;
+        let _ = self.stdout.write_all(ui::ENTER_ALTERNATE_BUFFER_CODE);
+        let _ = self.stdout.write_all(ui::HIDE_CURSOR_CODE);
+        let _ = self.stdout.write_all(ui::MODE_256_COLORS_CODE);
+        self.stdout.flush().unwrap();
+    }
+
+    pub fn restore_screen(&mut self) {
+        if self.is_pipped {
+            return;
+        }
+
+        use io::Write;
+        let _ = self.stdout.write_all(ui::EXIT_ALTERNATE_BUFFER_CODE);
+        let _ = self.stdout.write_all(ui::SHOW_CURSOR_CODE);
+        let _ = self.stdout.write_all(ui::RESET_STYLE_CODE);
+        let _ = self.stdout.flush();
+    }
+
     pub fn update<'a>(
         &'a mut self,
         resize: Option<(usize, usize)>,
         keys: &[Key],
         stdin_bytes: &[u8],
         server_bytes: &[u8],
-    ) -> &'a [u8] {
+    ) -> (bool, &'a [u8]) {
         use io::Write;
 
         self.server_write_buf.clear();
@@ -330,6 +366,7 @@ impl<'stdout> ClientApplication<'stdout> {
             }
         }
 
+        let mut suspend = false;
         if !server_bytes.is_empty() {
             self.server_read_buf.extend_from_slice(server_bytes);
             let mut read_slice = &self.server_read_buf[..];
@@ -338,6 +375,7 @@ impl<'stdout> ClientApplication<'stdout> {
                 let previous_slice = read_slice;
                 match ServerEvent::deserialize(&mut read_slice) {
                     Ok(ServerEvent::Display(display)) => self.stdout.write_all(display).unwrap(),
+                    Ok(ServerEvent::Suspend) => suspend = true,
                     Ok(ServerEvent::CommandOutput(output)) => {
                         self.stdout.write_all(output.as_bytes()).unwrap();
                         self.stdout.write_all(b"\0").unwrap();
@@ -355,14 +393,29 @@ impl<'stdout> ClientApplication<'stdout> {
             self.stdout.flush().unwrap();
         }
 
-        self.server_write_buf.as_slice()
+        (suspend, self.server_write_buf.as_slice())
     }
 }
 impl<'stdout> Drop for ClientApplication<'stdout> {
     fn drop(&mut self) {
-        if !self.is_pipped {
-            restore_screen(&mut self.stdout);
-        }
+        self.restore_screen();
     }
 }
 
+pub fn set_panic_hook() {
+    static mut ORIGINAL_PANIC_HOOK: Option<Box<dyn Fn(&panic::PanicInfo) + Sync + Send + 'static>> =
+        None;
+    unsafe { ORIGINAL_PANIC_HOOK = Some(panic::take_hook()) };
+
+    panic::set_hook(Box::new(|info| unsafe {
+        if let Ok(mut file) = fs::File::create("pepper-crash.txt") {
+            use io::Write;
+            let _ = writeln!(file, "{}", info);
+        }
+
+        if let Some(ref hook) = ORIGINAL_PANIC_HOOK {
+            hook(info);
+        }
+    }));
+}
+
