@@ -379,7 +379,7 @@ fn run_client(args: Args, mut connection: UnixStream) {
     let stdout = io::stdout();
     let mut application = ClientApplication::new(client_handle, stdout.lock(), is_pipped);
     let bytes = application.init(args, is_first_client);
-    if connection.write(bytes).is_err() {
+    if connection.write_all(bytes).is_err() {
         return;
     }
 
@@ -401,8 +401,8 @@ fn run_client(args: Args, mut connection: UnixStream) {
         resize_signal = Some(signal);
 
         let size = get_terminal_size();
-        let (_, bytes) = application.update(Some(size), &[], &[], &[]);
-        if connection.write(bytes).is_err() {
+        let (_, bytes) = application.update(Some(size), &[Key::None], &[], &[]);
+        if connection.write_all(bytes).is_err() {
             return;
         }
     }
@@ -441,6 +441,7 @@ fn run_client(args: Args, mut connection: UnixStream) {
                     }
                     Ok(len) => {
                         let bytes = &buf[..len];
+                        
                         if is_pipped {
                             stdin_bytes = bytes;
                         } else {
@@ -458,7 +459,7 @@ fn run_client(args: Args, mut connection: UnixStream) {
             }
 
             let (suspend, bytes) = application.update(resize, &keys, stdin_bytes, server_bytes);
-            if connection.write(bytes).is_err() {
+            if connection.write_all(bytes).is_err() {
                 break;
             }
             if suspend {
