@@ -1,8 +1,10 @@
 #[cfg(windows)]
-mod windows;
+#[path = "windows.rs"]
+mod sys;
 
 #[cfg(target_os = "linux")]
-mod linux;
+#[path = "linux.rs"]
+mod sys;
 
 #[cfg(any(
     target_os = "macos",
@@ -11,16 +13,9 @@ mod linux;
     target_os = "openbsd",
     target_os = "dragonfly",
 ))]
-mod bsd;
+#[path = "bsd.rs"]
+mod sys;
 
 pub fn main() {
-    #[cfg(windows)]
-    windows::main();
-
-    #[cfg(target_os = "linux")]
-    linux::main();
-
-    #[cfg(target_os = "bsd")]
-    bsd::main();
+    sys::main();
 }
-
